summaryrefslogtreecommitdiffstats
path: root/net/802/fddi.c
diff options
context:
space:
mode:
Diffstat (limited to 'net/802/fddi.c')
-rw-r--r--net/802/fddi.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/net/802/fddi.c b/net/802/fddi.c
index 4dccc3a9e..7edee2bef 100644
--- a/net/802/fddi.c
+++ b/net/802/fddi.c
@@ -22,7 +22,8 @@
* 2 of the License, or (at your option) any later version.
*
* Changes
* Alan Cox : New arp/rebuild header
*/
#include <linux/config.h>
@@ -57,11 +58,11 @@ int fddi_header(struct sk_buff *skb, struct net_device *dev, unsigned short type
int hl = FDDI_K_SNAP_HLEN;
struct fddihdr *fddi;
- if(type != ETH_P_IP && type != ETH_P_ARP)
+ if(type != ETH_P_IP && type != ETH_P_IPV6 && type != ETH_P_ARP)
hl=FDDI_K_8022_HLEN-3;
fddi = (struct fddihdr *)skb_push(skb, hl);
fddi->fc = FDDI_FC_K_ASYNC_LLC_DEF;
- if(type == ETH_P_IP || type == ETH_P_ARP)
+ if(type == ETH_P_IP || type == ETH_P_IPV6 || type == ETH_P_ARP)
{
fddi->hdr.llc_snap.dsap = FDDI_EXTENDED_SAP;
fddi->hdr.llc_snap.ssap = FDDI_EXTENDED_SAP;
@@ -22,7 +22,8 @@
*
* Changes
- * Alan Cox : New arp/rebuild header
+ * Alan Cox : New arp/rebuild header
+ * Maciej W. Rozycki : IPv6 support
*/
#include <linux/config.h>